Class: Google::Cloud::SecurityCenter::V1::AgentAnomaly
- Inherits:
-
Object
- Object
- Google::Cloud::SecurityCenter::V1::AgentAnomaly
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securitycenter/v1/agent_anomaly.rb
Overview
Represents details about an anomaly detected in an AI agent's behavior.
Instance Attribute Summary collapse
-
#confidence_score ⇒ ::Float
The overall confidence score indicating the likelihood that this session contains a true anomaly.
-
#detector_references ⇒ ::Array<::Google::Cloud::SecurityCenter::V1::DetectorReference>
The list of references to specific detectors that identified anomalies within this session.
-
#invocation_references ⇒ ::Array<::Google::Cloud::SecurityCenter::V1::InvocationReference>
References to the OpenTelemetry invocations.
Instance Attribute Details
#confidence_score ⇒ ::Float
Returns The overall confidence score indicating the likelihood that this session contains a true anomaly. The score ranges from 0.0 to 1.0, where 1.0 signifies 100% confidence in the presence of an anomaly and 0.0 signifies 0% confidence.
38 39 40 41 |
# File 'proto_docs/google/cloud/securitycenter/v1/agent_anomaly.rb', line 38 class AgentAnomaly include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#detector_references ⇒ ::Array<::Google::Cloud::SecurityCenter::V1::DetectorReference>
Returns The list of references to specific detectors that identified anomalies within this session.
38 39 40 41 |
# File 'proto_docs/google/cloud/securitycenter/v1/agent_anomaly.rb', line 38 class AgentAnomaly include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#invocation_references ⇒ ::Array<::Google::Cloud::SecurityCenter::V1::InvocationReference>
Returns References to the OpenTelemetry invocations.
38 39 40 41 |
# File 'proto_docs/google/cloud/securitycenter/v1/agent_anomaly.rb', line 38 class AgentAnomaly include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |