Class: Google::Cloud::SecurityCenter::V1::CloudDlpDataProfile
- Inherits:
-
Object
- Object
- Google::Cloud::SecurityCenter::V1::CloudDlpDataProfile
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securitycenter/v1/cloud_dlp_data_profile.rb
Overview
The data profile associated with the finding.
Defined Under Namespace
Modules: ParentType
Instance Attribute Summary collapse
-
#data_profile ⇒ ::String
Name of the data profile, for example,
projects/123/locations/europe/tableProfiles/8383929. -
#info_types ⇒ ::Array<::Google::Cloud::SecurityCenter::V1::InfoType>
Type of information detected by SDP.
-
#parent_type ⇒ ::Google::Cloud::SecurityCenter::V1::CloudDlpDataProfile::ParentType
The resource hierarchy level at which the data profile was generated.
Instance Attribute Details
#data_profile ⇒ ::String
Returns Name of the data profile, for example,
projects/123/locations/europe/tableProfiles/8383929.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'proto_docs/google/cloud/securitycenter/v1/cloud_dlp_data_profile.rb', line 38 class CloudDlpDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parents for configurations that produce data profile findings. module ParentType # Unspecified parent type. PARENT_TYPE_UNSPECIFIED = 0 # Organization-level configurations. ORGANIZATION = 1 # Project-level configurations. PROJECT = 2 end end |
#info_types ⇒ ::Array<::Google::Cloud::SecurityCenter::V1::InfoType>
Returns Type of information detected by SDP. Info type includes name, version and sensitivity of the detected information type.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'proto_docs/google/cloud/securitycenter/v1/cloud_dlp_data_profile.rb', line 38 class CloudDlpDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parents for configurations that produce data profile findings. module ParentType # Unspecified parent type. PARENT_TYPE_UNSPECIFIED = 0 # Organization-level configurations. ORGANIZATION = 1 # Project-level configurations. PROJECT = 2 end end |
#parent_type ⇒ ::Google::Cloud::SecurityCenter::V1::CloudDlpDataProfile::ParentType
Returns The resource hierarchy level at which the data profile was generated.
38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'proto_docs/google/cloud/securitycenter/v1/cloud_dlp_data_profile.rb', line 38 class CloudDlpDataProfile include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Parents for configurations that produce data profile findings. module ParentType # Unspecified parent type. PARENT_TYPE_UNSPECIFIED = 0 # Organization-level configurations. ORGANIZATION = 1 # Project-level configurations. PROJECT = 2 end end |