Class: Google::Cloud::SecurityCenter::V1::Finding::MuteInfo

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securitycenter/v1/finding.rb

Overview

Mute information about the finding, including whether the finding has a static mute or any matching dynamic mute rules.

Defined Under Namespace

Classes: DynamicMuteRecord, StaticMute

Instance Attribute Summary collapse

Instance Attribute Details

#dynamic_mute_records::Array<::Google::Cloud::SecurityCenter::V1::Finding::MuteInfo::DynamicMuteRecord>

Returns The list of dynamic mute rules that currently match the finding.

Returns:



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'proto_docs/google/cloud/securitycenter/v1/finding.rb', line 279

class MuteInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Information about the static mute state. A static mute state overrides
  # any dynamic mute rules that apply to this finding. The static mute state
  # can be set by a static mute rule or by muting the finding directly.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::SecurityCenter::V1::Finding::Mute]
  #     The static mute state. If the value is `MUTED` or `UNMUTED`, then the
  #     finding's overall mute state will have the same value.
  # @!attribute [rw] apply_time
  #   @return [::Google::Protobuf::Timestamp]
  #     When the static mute was applied.
  class StaticMute
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The record of a dynamic mute rule that matches the finding.
  # @!attribute [rw] mute_config
  #   @return [::String]
  #     The relative resource name of the mute rule, represented by a mute
  #     config, that created this record, for example
  #     `organizations/123/muteConfigs/mymuteconfig` or
  #     `organizations/123/locations/global/muteConfigs/mymuteconfig`.
  # @!attribute [rw] match_time
  #   @return [::Google::Protobuf::Timestamp]
  #     When the dynamic mute rule first matched the finding.
  class DynamicMuteRecord
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#static_mute::Google::Cloud::SecurityCenter::V1::Finding::MuteInfo::StaticMute

Returns If set, the static mute applied to this finding. Static mutes override dynamic mutes. If unset, there is no static mute.

Returns:



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'proto_docs/google/cloud/securitycenter/v1/finding.rb', line 279

class MuteInfo
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Information about the static mute state. A static mute state overrides
  # any dynamic mute rules that apply to this finding. The static mute state
  # can be set by a static mute rule or by muting the finding directly.
  # @!attribute [rw] state
  #   @return [::Google::Cloud::SecurityCenter::V1::Finding::Mute]
  #     The static mute state. If the value is `MUTED` or `UNMUTED`, then the
  #     finding's overall mute state will have the same value.
  # @!attribute [rw] apply_time
  #   @return [::Google::Protobuf::Timestamp]
  #     When the static mute was applied.
  class StaticMute
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # The record of a dynamic mute rule that matches the finding.
  # @!attribute [rw] mute_config
  #   @return [::String]
  #     The relative resource name of the mute rule, represented by a mute
  #     config, that created this record, for example
  #     `organizations/123/muteConfigs/mymuteconfig` or
  #     `organizations/123/locations/global/muteConfigs/mymuteconfig`.
  # @!attribute [rw] match_time
  #   @return [::Google::Protobuf::Timestamp]
  #     When the dynamic mute rule first matched the finding.
  class DynamicMuteRecord
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end