Class: Google::Cloud::SecurityCenter::V1::SensitivityScore

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/securitycenter/v1/cloud_dlp_data_profile.rb

Overview

Score is calculated from of all elements in the data profile. A higher level means the data is more sensitive.

Defined Under Namespace

Modules: SensitivityScoreLevel

Instance Attribute Summary collapse

Instance Attribute Details

#score::Google::Cloud::SecurityCenter::V1::SensitivityScore::SensitivityScoreLevel

Returns The sensitivity score applied to the resource.

Returns:



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'proto_docs/google/cloud/securitycenter/v1/cloud_dlp_data_profile.rb', line 82

class SensitivityScore
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Various sensitivity score levels for resources.
  module SensitivityScoreLevel
    # Unused.
    SENSITIVITY_SCORE_LEVEL_UNSPECIFIED = 0

    # No sensitive information detected. The resource isn't publicly
    # accessible.
    SENSITIVITY_LOW = 10

    # Unable to determine sensitivity.
    SENSITIVITY_UNKNOWN = 12

    # Medium risk. Contains personally identifiable information (PII),
    # potentially sensitive data, or fields with free-text data that are at a
    # higher risk of having intermittent sensitive data. Consider limiting
    # access.
    SENSITIVITY_MODERATE = 20

    # High risk. Sensitive personally identifiable information (SPII) can be
    # present. Exfiltration of data can lead to user data loss.
    # Re-identification of users might be possible. Consider limiting usage and
    # or removing SPII.
    SENSITIVITY_HIGH = 30
  end
end