Class: Google::Cloud::SecurityCenter::V1::Agent
- Inherits:
-
Object
- Object
- Google::Cloud::SecurityCenter::V1::Agent
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securitycenter/v1/agent.rb
Overview
Represents a monitored AI Agent.
Instance Attribute Summary collapse
-
#display_name ⇒ ::String
The user friendly name of the specific agent instance where the finding was detected, for example, "Banking Agent".
-
#id ⇒ ::String
Identifier of the agent.
Instance Attribute Details
#display_name ⇒ ::String
Returns The user friendly name of the specific agent instance where the finding was detected, for example, "Banking Agent".
32 33 34 35 |
# File 'proto_docs/google/cloud/securitycenter/v1/agent.rb', line 32 class Agent include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |