Class: Google::Cloud::SecurityCenter::V1::ExternalExposure
- Inherits:
-
Object
- Object
- Google::Cloud::SecurityCenter::V1::ExternalExposure
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/securitycenter/v1/external_exposure.rb
Overview
Details about the externally exposed resource associated with the finding.
Instance Attribute Summary collapse
-
#backend_service ⇒ ::String
The full resource name of load balancer backend service, for example, "//compute.googleapis.com/projects/{project-id}/global/backendServices/{name}".
-
#exposed_endpoint ⇒ ::String
The resource which is running the exposed service, for example, "//compute.googleapis.com/projects/{project-id}/zones/{zone}/instances/{instance}.”.
-
#exposed_service ⇒ ::String
The name and version of the service, for example, "Jupyter Notebook 6.14.0".
-
#forwarding_rule ⇒ ::String
The full resource name of the forwarding rule, for example, "//compute.googleapis.com/projects/{project-id}/global/forwardingRules/{forwarding-rule-name}".
-
#instance_group ⇒ ::String
The full resource name of the instance group, for example, "//compute.googleapis.com/projects/{project-id}/global/instanceGroups/{name}".
-
#load_balancer_firewall_policy ⇒ ::String
The full resource name of the load balancer firewall policy, for example, "//compute.googleapis.com/projects/{project-id}/global/firewallPolicies/{policy-name}".
-
#network_endpoint_group ⇒ ::String
The full resource name of the network endpoint group, for example, "//compute.googleapis.com/projects/{project-id}/global/networkEndpointGroups/{name}".
-
#private_ip_address ⇒ ::String
Private IP address of the exposed endpoint.
-
#private_port ⇒ ::String
Port number associated with private IP address.
-
#public_ip_address ⇒ ::String
Public IP address of the exposed endpoint.
-
#public_port ⇒ ::String
Public port number of the exposed endpoint.
-
#service_firewall_policy ⇒ ::String
The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/{project-id}/global/firewallPolicies/{policy-name}".
Instance Attribute Details
#backend_service ⇒ ::String
Returns The full resource name of load balancer backend service, for example, "//compute.googleapis.com/projects/{project-id}/global/backendServices/{name}".
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exposed_endpoint ⇒ ::String
Returns The resource which is running the exposed service, for example, "//compute.googleapis.com/projects/{project-id}/zones/{zone}/instances/{instance}.”.
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#exposed_service ⇒ ::String
Returns The name and version of the service, for example, "Jupyter Notebook 6.14.0".
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#forwarding_rule ⇒ ::String
Returns The full resource name of the forwarding rule, for example, "//compute.googleapis.com/projects/{project-id}/global/forwardingRules/{forwarding-rule-name}".
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#instance_group ⇒ ::String
Returns The full resource name of the instance group, for example, "//compute.googleapis.com/projects/{project-id}/global/instanceGroups/{name}".
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#load_balancer_firewall_policy ⇒ ::String
Returns The full resource name of the load balancer firewall policy, for example, "//compute.googleapis.com/projects/{project-id}/global/firewallPolicies/{policy-name}".
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#network_endpoint_group ⇒ ::String
Returns The full resource name of the network endpoint group, for example, "//compute.googleapis.com/projects/{project-id}/global/networkEndpointGroups/{name}".
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#private_ip_address ⇒ ::String
Returns Private IP address of the exposed endpoint.
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#private_port ⇒ ::String
Returns Port number associated with private IP address.
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#public_ip_address ⇒ ::String
Returns Public IP address of the exposed endpoint.
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#public_port ⇒ ::String
Returns Public port number of the exposed endpoint.
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#service_firewall_policy ⇒ ::String
Returns The full resource name of the firewall policy of the exposed service, for example, "//compute.googleapis.com/projects/{project-id}/global/firewallPolicies/{policy-name}".
70 71 72 73 |
# File 'proto_docs/google/cloud/securitycenter/v1/external_exposure.rb', line 70 class ExternalExposure include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |