Module: Google::Cloud::SecurityCenter::V1::Finding::FindingClass
- Defined in:
- proto_docs/google/cloud/securitycenter/v1/finding.rb
Overview
Represents what kind of Finding it is.
Constant Summary collapse
- FINDING_CLASS_UNSPECIFIED =
Unspecified finding class.
0- THREAT =
Describes unwanted or malicious activity.
1- VULNERABILITY =
Describes a potential weakness in software that increases risk to Confidentiality & Integrity & Availability.
2- MISCONFIGURATION =
Describes a potential weakness in cloud resource/asset configuration that increases risk.
3- OBSERVATION =
Describes a security observation that is for informational purposes.
4- SCC_ERROR =
Describes an error that prevents some SCC functionality.
5- POSTURE_VIOLATION =
Describes a potential security risk due to a change in the security posture.
6- TOXIC_COMBINATION =
Describes a group of security issues that, when the issues occur together, represent a greater risk than when the issues occur independently. A group of such issues is referred to as a toxic combination.
7- SENSITIVE_DATA_RISK =
Describes a potential security risk to data assets that contain sensitive data.
8- CHOKEPOINT =
Describes a resource or resource group where high risk attack paths converge, based on attack path simulations (APS).
9- EXTERNAL_EXPOSURE =
Describes a potential security risk due to the resource being exposed to the internet.
10