Module: Google::Cloud::SecurityCenter::V1::SensitivityScore::SensitivityScoreLevel
- Defined in:
- proto_docs/google/cloud/securitycenter/v1/cloud_dlp_data_profile.rb
Overview
Various sensitivity score levels for resources.
Constant Summary collapse
- SENSITIVITY_SCORE_LEVEL_UNSPECIFIED =
Unused.
0- SENSITIVITY_LOW =
No sensitive information detected. The resource isn't publicly accessible.
10- SENSITIVITY_UNKNOWN =
Unable to determine sensitivity.
12- SENSITIVITY_MODERATE =
Medium risk. Contains personally identifiable information (PII), potentially sensitive data, or fields with free-text data that are at a higher risk of having intermittent sensitive data. Consider limiting access.
20- SENSITIVITY_HIGH =
High risk. Sensitive personally identifiable information (SPII) can be present. Exfiltration of data can lead to user data loss. Re-identification of users might be possible. Consider limiting usage and or removing SPII.
30